/* SPDX-License-Identifier: LGPL-2.1+ */

#ifndef __LXC_VERSION_H
#define __LXC_VERSION_H

#define LXC_DEVEL 0
#define LXC_VERSION_MAJOR 7
#define LXC_VERSION_MINOR 0
#define LXC_VERSION_MICRO 0
#define LXC_VERSION_ABI "1.9.0"
#define LXC_VERSION "7.0.0"

#endif
